@@ -1,5 +1,5 @@
 package IRC::Mode::Set;
-$IRC::Mode::Set::VERSION = '0.089001';
+$IRC::Mode::Set::VERSION = '0.090001';
 use strictures 1;
 use Carp;
 
@@ -97,7 +97,7 @@ sub split_mode_set {
 
 sub clone {
   my ($self) = @_;
-  (ref $self)->new(mode_array => dclone($self->mode_array))
+  (blessed $self)->new(mode_array => dclone($self->mode_array))
 }
 
 sub clone_from_mode {
@@ -185,7 +185,7 @@ IRC::Mode::Set - A set of parsed IRC mode changes
     mode_string => '+o-o+v avenj Joah Gilded',
 
     ## Optionally specify modes that take parameters (always or when set)
-    ## defaults, should vaguely match ISUPPORT CHANMODES parameters:
+    ## Defaults:
     param_always => 'bkohv',
     param_on_set => 'l',
   );
