@@ -1,20 +1,16 @@
 package IRC::Toolkit::TS6;
-$IRC::Toolkit::TS6::VERSION = '0.089001';
+$IRC::Toolkit::TS6::VERSION = '0.090001';
 use strictures 1;
 use Carp;
 
 use parent 'Exporter::Tiny';
-our @EXPORT = 'ts6_id';
-
-use namespace::clean;
-
-sub ts6_id {
-  __PACKAGE__->new(@_)
-}
+sub ts6_id { __PACKAGE__->new(@_) }
+our @EXPORT = our @EXPORT_OK = 'ts6_id';
 
 use overload
-  bool => sub { 1 },
-  '""' => 'as_string',
+  bool  => sub { 1 },
+  '&{}' => sub { my $s = shift; sub { $s->next } },
+  '""'  => 'as_string',
   fallback => 1;
 
 =pod
@@ -23,16 +19,9 @@ use overload
 
 =cut
 
-sub new {
-  my ($class, $start) = @_;
-  my $self = [ split '', $start || 'A'x6 ];
-  bless $self, $class
-}
+sub new { bless [ split '', $_[1] || 'A'x6 ], $_[0] }
 
-sub as_string {
-  my ($self) = @_;
-  join '', @$self
-}
+sub as_string { join '', @{ $_[0] } }
 
 sub next {
   my ($self) = @_;
@@ -84,7 +73,12 @@ The exported B<ts6_id> function will instance a new ID object. B<ts6_id>
 optionally takes a start-point as a string (defaults to 'AAAAAA' similar to
 C<ratbox>).
 
-The object stringifies to the current ID.
+The object is overloaded in two ways; it stringifies to the current ID, and
+calling it as a C<CODE> ref is the same as calling L</next>:
+
+  my $idgen = ts6_id;
+  my $current = "$idgen";  # 'AAAAAA'
+  my $next = $idgen->();   # 'AAAAAB'
 
 =head2 as_string
 
@@ -96,7 +90,6 @@ The C<next> will increment the current ID and return the ID as a string.
 
 If no more IDs are available, B<next> will croak.
 
-
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>; conceptually derived from the relevant
